@@ -27,45 +27,12 @@ def test():
     """
     this is test function
     """
+    acc = main_prof.accounts[0]
 
-    acc = LivejAccount()
-    #acc1 = LivejAccount()
+    msg = acc.posts[0]
 
-    #acc1.username = "maemoblogs"
-    #acc1.passwd = "maemo100500"
-    #acc1.refresh_posts(cback)
+    acc.refresh_post(msg)
 
-    acc.username = "scribo-rpc"
-    acc.passwd = "test123"
-    #acc.date = None#"0000-00-00 00:00:00"#"2009-08-21 13:27:00" 
-    #acc.check_login()
-
-
-    #msg = Message(1)
-    #m = msg.copy()
-    #msg = Message(7)
-    #acc.edit_post(msg)
-
-    #acc.remove_friend(acc1)
-    #acc.add_comment()
-
-    #acc.test()
-    #acc._get_avatar('http://l-userpic.livejournal.com/9277267/484155')
-    #acc.refresh_friends_list()
-
-
-    try:
-        main_prof.add_account(acc)
-    except:
-        pass
-    else:
-        acc.refresh_friends_page(cback)
-    list = main_prof.get_friends_posts(1)
-    #acc.refresh_posts(cback)
-
-
-
-    #del(sql_driver)
     return None
 
 def get_uname(acc):
