@@ -288,8 +288,10 @@ class AddPostWindow(MainWindow):
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                 self.tr("Post is edit"),
                                                 QtGui.QMessageBox.Yes)
+            self.sending_post = True
+        
         mes.del_msg_tree()
-        self.sending_post = True
+        #self.sending_post = True
         try:
             author.refresh_post(self.msg)
         except WarningExc, exc:
@@ -533,14 +535,21 @@ class AddPostWindow(MainWindow):
         if not self.sending_post:
             ret = self.text_changed()
             if (ret == QtGui.QMessageBox.No):
+                event.ignore()
                 return
-        event.accept()
+            else:
+                event.accept()
+        else:
+            event.accept()
     
     def home_window(self):
         """
         check post on changing event
         """
+        print "home_add"
         ret = self.text_changed()
         if (ret == QtGui.QMessageBox.No):
                 return
-        super(AddPostWindow, self).home_window()
+        else:
+            self.sending_post = True
+            super(AddPostWindow, self).home_window()
