@@ -19,11 +19,6 @@ import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 
-#from MainWindow import main_window
-
-#sys.path.append("../ldm")
-#sys.path.append("..")
-
 from ldm.Profile import main_prof
 from ldm.Account import *
 from MainWindow import *
@@ -41,7 +36,6 @@ class HomePage(MainWindow):
         @return 
         """
         if not main_prof.accounts:
-            print "starts"
             from StartPage import start_page
         else:    
             super(HomePage, self).__init__(parent = None)
@@ -139,8 +133,8 @@ class HomePage(MainWindow):
         hbox = QtGui.QHBoxLayout()
         vbox1 = QtGui.QVBoxLayout()
         def_acc = main_prof.def_account
-        #label with personal information
 
+        #label with personal information
         self.info_label = QtGui.QLabel(self.fill_user_info(def_acc), self.centr_widg)
         self.info_label.setAlignment(QtCore.Qt.AlignLeft)
 
@@ -149,8 +143,8 @@ class HomePage(MainWindow):
 
         self.acc_combo_box = self.create_list_acc(def_acc)
         path_ava = def_acc.path_to_ava
-        # if user haven't userpic on service, it isn't added. 
 
+        # if user haven't userpic on service, it isn't added. 
         if path_ava:
             self.upic = QtGui.QImage(path_ava)
             self.image_label.setPixmap(QtGui.QPixmap.fromImage(self.upic))
@@ -161,9 +155,7 @@ class HomePage(MainWindow):
         vbox1.addWidget(self.acc_combo_box)
 
         hbox.addLayout(vbox1)
-        #hbox.addLayout(self.vbox2)
         hbox.addWidget(self.info_label)
-	#hbox.addStretch(1)
         return hbox
 
     def create_push_button_group(self):
@@ -203,8 +195,6 @@ class HomePage(MainWindow):
 
         from AddPost import AddPostWindow
         add_widg = AddPostWindow(self)
-    
-
 
     def list_my_posts(self):
         """                                                                                                                                                 
@@ -214,8 +204,6 @@ class HomePage(MainWindow):
         """
         from ListMyPosts import ListMyPosts
         widg = ListMyPosts(self)
-    
-
 
     def list_friends_posts(self):
         """                                                                                                                                                 
@@ -225,5 +213,3 @@ class HomePage(MainWindow):
         """
         from ListFriendsPosts import ListFriendsPosts
         widg = ListFriendsPosts(self)
-    
-#home_window = HomePage()
\ No newline at end of file
