@@ -23,11 +23,9 @@ class ListFriendsPosts(ListMyPosts):
         initialization "list of posts" window                                                                                                               
         @return                                                                                                                                             
         """
-        print "begin_init"
         self.parent = parent
         super(ListFriendsPosts, self).__init__(parent)
-        print "end_init" 
-    
+            
     def refresh_messages(self):
         list_acc = main_prof.accounts
         for acc in list_acc:
@@ -47,5 +45,5 @@ class ListFriendsPosts(ListMyPosts):
         file_tool_bar = super(ListFriendsPosts, self).create_toolbar()
         self.refresh_act.setText(self.tr("Refresh"))
         self.del_act.setDisabled(True)
-        #self.del_act.deleteLater()
+        self.del_act.setText(self.tr("Delete"))
         return file_tool_bar
