@@ -168,10 +168,18 @@ class ListMyPosts(MainWindow):
             for item in list:
                 index = item.data(1).toString().toInt()[0]
                 mes = self.list[index]
+                
                 try:
                     mes.poster.del_post(mes)
                 except WarningExc, exc:
-                    main_window.show_warning(exc)
+                    author = mes.poster
+                    try:
+                        author.refresh_post(mes)
+                    except WarningExc, ex:
+                        super(ListMyPosts, self).show_warning(ex)
+                        return
+                    else:
+                        main_window.show_warning(exc)
                 else:
                     self.mes_list.removeItemWidget(item)
                     item.setHidden(True)
