@@ -182,7 +182,7 @@ class RepeatPost(MainWindow):
                                                 self.tr("Post was sent"),
                                                 QtGui.QMessageBox.Yes)
             self.parent.sending_post = True
-        super(RepeatPost, self).home_window()
+            super(RepeatPost, self).home_window()
 
     def home_window(self):
         """
@@ -195,6 +195,9 @@ class RepeatPost(MainWindow):
                                QtGui.QMessageBox.No)
         if (ret == QtGui.QMessageBox.No):
                 return
+                
+        #don't ask twice
+        self.parent.sending_post = True
         super(RepeatPost, self).home_window()
         
 from AddPost import *
