@@ -10,9 +10,6 @@
 import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
-
-
-
 from ldm.Profile import main_prof
 from ldm.Account import Account
 from services.Dispatcher import dispatcher
@@ -39,7 +36,6 @@ class StartPage(MainWindow):
         @return
         """
         super(StartPage, self).__init__(parent)
-        print "start page"
         self.parent = parent
         self.centr_widg = QtGui.QWidget(self)
         login_label = QtGui.QLabel(self.tr("Login"), self.centr_widg)
@@ -49,7 +45,6 @@ class StartPage(MainWindow):
         service_label = QtGui.QLabel(self.tr("Blog service"), self.centr_widg)
         service_label.setAlignment(QtCore.Qt.AlignRight)
 
-        #from MainWindow import main_window
         self.new_act.setDisabled(True)
         self.manage_act.setDisabled(True)
 
@@ -60,7 +55,6 @@ class StartPage(MainWindow):
         self.serv_combo = self.fill_combo()
 
         start_button = QtGui.QPushButton(self.tr("Go"), self)
-        #start_button.setIcon(QtGui.QIcon("../data/key.png"))
         self.connect(start_button, QtCore.SIGNAL("clicked()"), self.add_account)
 
         grid = QtGui.QGridLayout()
@@ -76,7 +70,6 @@ class StartPage(MainWindow):
         self.centr_widg.setLayout(self.create_start(grid))
         self.setCentralWidget(self.centr_widg)
         self.show()
-        print "end_start"
 
     def fill_combo(self):
         """
@@ -101,7 +94,6 @@ class StartPage(MainWindow):
         handler fo buttons Go(authentification)
         @return
         """
-        print "add _accoent"
         if (self.login_edit.text() == "") or (self.pasw_edit.text() == ""):
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                self.tr("Please, fill all fields!"),
@@ -111,33 +103,37 @@ class StartPage(MainWindow):
         if self._add_new_account():
             self.new_act.setDisabled(False)
             self.manage_act.setDisabled(False)
-            print "home_page"
             self.hide()
             from HomePage import HomePage
             home_page = HomePage()
             self.parent = home_page
             super(StartPage, self).home_window()
             
-
+    
     def _add_new_account(self):
+	"""
+	inside method adding new account
+	"""
         index = self.serv_combo.currentIndex()
 
         service = dispatcher.get_services()[index]
-        username = str(self.login_edit.text())
+        username = unicode(self.login_edit.text())
         acc = Account.register(service, username)
-        acc.passwd = str(self.pasw_edit.text())
+        acc.passwd = unicode(self.pasw_edit.text())
 
         main_prof.add_account(acc)
 
         try:
             acc.check_login()
         except WarningExc, exc:
+            main_prof.remove_account(acc)
             super(StartPage, self).show_warning(exc)
             return False
 
         try:
             acc.refresh_user_info()
         except WarningExc, exc:
+            main_prof.remove_account(acc)
             super(StartPage, self).show_warning(exc)
             return False
 
